Index: src/gpu/gl/GrGLCreateNullInterface.cpp |
diff --git a/src/gpu/gl/GrGLCreateNullInterface.cpp b/src/gpu/gl/GrGLCreateNullInterface.cpp |
index 37d02850098ccfe47a189b2dc2a9a884fff4998b..1ed5f65e5c2112e269ca5b3dd185b8c4a3ae86c4 100644 |
--- a/src/gpu/gl/GrGLCreateNullInterface.cpp |
+++ b/src/gpu/gl/GrGLCreateNullInterface.cpp |
@@ -22,7 +22,7 @@ class BufferObj { |
public: |
- BufferObj(GrGLuint id) : fID(id), fDataPtr(NULL), fSize(0), fMapped(false) { |
+ BufferObj(GrGLuint id) : fID(id), fDataPtr(nullptr), fSize(0), fMapped(false) { |
} |
~BufferObj() { delete[] fDataPtr; } |
@@ -58,11 +58,11 @@ public: |
BufferManager() : fFreeListHead(kFreeListEnd) {} |
~BufferManager() { |
// NULL out the entries that are really free list links rather than ptrs before deleting. |
intptr_t curr = fFreeListHead; |
while (kFreeListEnd != curr) { |
intptr_t next = reinterpret_cast<intptr_t>(fBuffers[SkToS32(curr)]); |
- fBuffers[SkToS32(curr)] = NULL; |
+ fBuffers[SkToS32(curr)] = nullptr; |
curr = next; |
} |
@@ -260,7 +260,7 @@ GrGLvoid* GR_GL_FUNCTION_TYPE nullGLMapBufferRange(GrGLenum target, GrGLintptr o |
buffer->setMapped(true); |
return buffer->dataPtr(); |
} |
- return NULL; |
+ return nullptr; |
} |
GrGLvoid* GR_GL_FUNCTION_TYPE nullGLMapBuffer(GrGLenum target, GrGLenum access) { |
@@ -283,7 +283,7 @@ GrGLvoid* GR_GL_FUNCTION_TYPE nullGLMapBuffer(GrGLenum target, GrGLenum access) |
} |
SkASSERT(false); |
- return NULL; // no buffer bound to target |
+ return nullptr; // no buffer bound to target |
} |
GrGLvoid GR_GL_FUNCTION_TYPE nullGLFlushMappedBufferRange(GrGLenum target, |
@@ -58,11 +58,11 @@ public: |
BufferManager() : fFreeListHead(kFreeListEnd) {} |
~BufferManager() { |
- // NULL out the entries that are really free list links rather than ptrs before deleting. |
+ // nullptr out the entries that are really free list links rather than ptrs before deleting. |
intptr_t curr = fFreeListHead; |
while (kFreeListEnd != curr) { |